Move ao_match_word from ao_ignite.c to ao_cmd.c
[fw/altos] / src / ao.h
index e86b4bf99cf81840f95bd876a911deb31f842c31..508ed37a47c65027ee9705781857956c7470c94e 100644 (file)
--- a/src/ao.h
+++ b/src/ao.h
@@ -40,6 +40,7 @@
 /* An AltOS task */
 struct ao_task {
        __xdata void *wchan;            /* current wait channel (NULL if running) */
+       uint16_t alarm;                 /* abort ao_sleep time */
        uint8_t stack_count;            /* amount of saved stack */
        uint8_t task_id;                /* index in the task array */
        __code char *name;              /* task name */
@@ -55,8 +56,12 @@ extern __xdata struct ao_task *__data ao_cur_task;
  ao_task.c
  */
 
-/* Suspend the current task until wchan is awoken */
-void
+/* Suspend the current task until wchan is awoken.
+ * returns:
+ *  0 on normal wake
+ *  1 on alarm
+ */
+uint8_t
 ao_sleep(__xdata void *wchan);
 
 /* Wake all tasks sleeping on wchan */
@@ -67,6 +72,10 @@ ao_wakeup(__xdata void *wchan);
 void
 ao_wake_task(__xdata struct ao_task *task);
 
+/* set an alarm to go off in 'delay' ticks */
+void
+ao_alarm(uint16_t delay);
+
 /* Yield the processor to another task */
 void
 ao_yield(void) _naked;
@@ -97,6 +106,7 @@ ao_start_scheduler(void);
 #define AO_PANIC_EE            4       /* Mis-using eeprom API */
 #define AO_PANIC_LOG           5       /* Failing to read/write log data */
 #define AO_PANIC_CMD           6       /* Too many command sets registered */
+#define AO_PANIC_STDIO         7       /* Too many stdio handlers registered */
 
 /* Stop the operating system, beeping and blinking the reason */
 void
@@ -107,8 +117,9 @@ ao_panic(uint8_t reason);
  */
 
 /* Our timer runs at 100Hz */
-#define AO_MS_TO_TICKS(ms)     ((ms) / 10)
-#define AO_SEC_TO_TICKS(s)     ((s) * 100)
+#define AO_HERTZ               100
+#define AO_MS_TO_TICKS(ms)     ((ms) / (1000 / AO_HERTZ))
+#define AO_SEC_TO_TICKS(s)     ((s) * AO_HERTZ)
 
 /* Returns the current time in ticks */
 uint16_t
@@ -281,6 +292,12 @@ ao_usb_putchar(char c);
 char
 ao_usb_getchar(void);
 
+/* Poll for a charcter on the USB input queue.
+ * returns AO_READ_AGAIN if none are available
+ */
+char
+ao_usb_pollchar(void);
+
 /* Flush the USB output queue */
 void
 ao_usb_flush(void);
@@ -333,6 +350,9 @@ ao_cmd_hex(void);
 void
 ao_cmd_decimal(void);
 
+uint8_t
+ao_match_word(__code char *word);
+
 struct ao_cmds {
        char            cmd;
        void            (*func)(void);
@@ -356,7 +376,6 @@ ao_cmd_init(void);
 
 #define AO_DMA_DONE    1
 #define AO_DMA_ABORTED 2
-#define AO_DMA_TIMEOUT 4
 
 uint8_t
 ao_dma_alloc(__xdata uint8_t * done);
@@ -380,7 +399,7 @@ ao_dma_trigger(uint8_t id);
 
 /* Abort a running DMA transfer */
 void
-ao_dma_abort(uint8_t id, uint8_t reason);
+ao_dma_abort(uint8_t id);
 
 /* DMA interrupt routine */
 void
@@ -768,6 +787,7 @@ ao_gps_report_init(void);
  */
 
 #define AO_MAX_CALLSIGN                8
+#define AO_TELEMETRY_VERSION   1
 
 struct ao_telemetry {
        uint8_t                 addr;
@@ -777,6 +797,8 @@ struct ao_telemetry {
        int32_t                 flight_vel;
        int16_t                 flight_pres;
        int16_t                 ground_pres;
+       int16_t                 accel_plus_g;
+       int16_t                 accel_minus_g;
        struct ao_adc           adc;
        struct ao_gps_data      gps;
        char                    callsign[AO_MAX_CALLSIGN];
@@ -804,8 +826,12 @@ ao_telemetry_init(void);
 
 extern __xdata uint8_t ao_radio_dma;
 extern __xdata uint8_t ao_radio_dma_done;
+extern __xdata uint8_t ao_radio_done;
 extern __xdata uint8_t ao_radio_mutex;
 
+void
+ao_radio_general_isr(void) interrupt 16;
+
 void
 ao_radio_set_telemetry(void);
 
@@ -831,7 +857,7 @@ void
 ao_radio_rdf(int ms);
 
 void
-ao_radio_abort(uint8_t reason);
+ao_radio_abort(void);
 
 void
 ao_radio_rdf_abort(void);
@@ -861,9 +887,24 @@ ao_monitor_init(uint8_t led, uint8_t monitoring) __reentrant;
  * ao_stdio.c
  */
 
+#define AO_READ_AGAIN  ((char) -1)
+
+struct ao_stdio {
+       char    (*pollchar)(void);
+       void    (*putchar)(char c) __reentrant;
+       void    (*flush)(void);
+};
+
 void
 flush(void);
 
+extern __xdata uint8_t ao_stdin_ready;
+
+void
+ao_add_stdio(char (*pollchar)(void),
+            void (*putchar)(char) __reentrant,
+            void (*flush)(void));
+
 /*
  * ao_ignite.c
  */
@@ -894,16 +935,17 @@ ao_igniter_init(void);
  */
 
 #define AO_CONFIG_MAJOR        1
-#define AO_CONFIG_MINOR        1
+#define AO_CONFIG_MINOR        2
 
 struct ao_config {
        uint8_t         major;
        uint8_t         minor;
        uint16_t        main_deploy;
-       int16_t         accel_zero_g;
+       int16_t         accel_plus_g;
        uint8_t         radio_channel;
        char            callsign[AO_MAX_CALLSIGN + 1];
        uint8_t         apogee_delay;
+       int16_t         accel_minus_g;
 };
 
 extern __xdata struct ao_config ao_config;
@@ -969,6 +1011,7 @@ struct ao_fifo {
  */
 
 #define AO_PACKET_MAX  8
+#define AO_PACKET_SYN          (uint8_t) 0xff
 
 struct ao_packet {
        uint8_t         addr;
@@ -984,7 +1027,42 @@ struct ao_packet_recv {
        uint8_t                 status;
 };
 
+extern __xdata struct ao_packet_recv ao_rx_packet;
+extern __xdata struct ao_packet ao_tx_packet;
+extern __xdata struct ao_task  ao_packet_task;
+extern __xdata uint8_t ao_packet_enable;
+extern __xdata uint8_t ao_packet_master_sleeping;
+extern __pdata uint8_t ao_packet_rx_len, ao_packet_rx_used, ao_packet_tx_used;
+
+void
+ao_packet_send(void);
+
+uint8_t
+ao_packet_recv(void);
+
+void
+ao_packet_flush(void);
+
+void
+ao_packet_putchar(char c) __reentrant;
+
+char
+ao_packet_pollchar(void) __critical;
+
+/* ao_packet_master.c */
+
+void
+ao_packet_master_init(void);
+
+/* ao_packet_slave.c */
+
+void
+ao_packet_slave_start(void);
+
+void
+ao_packet_slave_stop(void);
+
 void
-ao_packet_init(void);
+ao_packet_slave_init(void);
 
 #endif /* _AO_H_ */